<!-- SPDX-FileCopyrightText: 2026 PythonWoods <dev@pythonwoods.dev> -->
<!-- SPDX-License-Identifier: Apache-2.0 -->

# README

TRAP: Double Index — both index.md and README.md exist in the same directory.
Both map to `/` → CONFLICT.
